chordtools.Chord
================

.. abjad-lineage:: abjad.tools.chordtools.Chord.Chord.Chord

.. autoclass:: abjad.tools.chordtools.Chord.Chord.Chord
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.descendants
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.duration_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.fingered_pitches
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.leaf_index
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.lineage
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.multiplied_duration
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.override
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.parent
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.parentage
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.preprolated_duration
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.prolated_duration
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.prolation
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.set
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.sounding_pitches
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.spanners
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.start_offset
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.start_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.stop_offset
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.stop_offset_in_seconds
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.storage_format
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.timespan
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.timespan_in_seconds
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.duration_multiplier
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.note_heads
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_duration
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_at_sounding_pitch
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitch_indication_is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.chordtools.Chord.Chord.Chord.written_pitches
   :noindex:

Methods
-------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.append
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.clear
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.extend
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.pop
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.remove
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__and__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__contains__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__delitem__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__eq__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__ge__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__getitem__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__gt__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__le__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__len__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__lt__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__mul__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__ne__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__or__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__repr__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__rmul__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__setitem__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__str__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__sub__
   :noindex:

.. automethod:: abjad.tools.chordtools.Chord.Chord.Chord.__xor__
   :noindex:
